==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/GCPKMSKeyReferenceFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GCPKMSKeyReferenceFluent<A extends GCPKMSKeyReferenceFluent<A>> extends BaseFluent<A>{
  public GCPKMSKeyReferenceFluent() {
  }
  public GCPKMSKeyReferenceFluent(GCPKMSKeyReference instance) {
    instance = (instance != null ? instance : new GCPKMSKeyReference());

    if (instance != null) {
      this.withKeyRing(instance.getKeyRing());
      this.withLocation(instance.getLocation());
      this.withName(instance.getName());
      this.withProjectID(instance.getProjectID());
      this.withKeyRing(instance.getKeyRing());
      this.withLocation(instance.getLocation());
      this.withName(instance.getName());
      this.withProjectID(instance.getProjectID());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String keyRing;
  private String location;
  private String name;
  private String projectID;
  private Map<String,Object> additionalProperties;
  public String getKeyRing() {
    return this.keyRing;
  }
  public A withKeyRing(String keyRing) {
    this.keyRing=keyRing; return (A) this;
  }
  public boolean hasKeyRing() {
    return this.keyRing != null;
  }
  public String getLocation() {
    return this.location;
  }
  public A withLocation(String location) {
    this.location=location; return (A) this;
  }
  public boolean hasLocation() {
    return this.location != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getProjectID() {
    return this.projectID;
  }
  public A withProjectID(String projectID) {
    this.projectID=projectID; return (A) this;
  }
  public boolean hasProjectID() {
    return this.projectID != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GCPKMSKeyReferenceFluent that = (GCPKMSKeyReferenceFluent) o;
    if (!java.util.Objects.equals(keyRing, that.keyRing)) return false;

    if (!java.util.Objects.equals(location, that.location)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(projectID, that.projectID)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(keyRing,  location,  name,  projectID,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (keyRing != null) { sb.append("keyRing:"); sb.append(keyRing + ","); }
    if (location != null) { sb.append("location:"); sb.append(location + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (projectID != null) { sb.append("projectID:"); sb.append(projectID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/GCPKMSKeyReferenceFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GCPKMSKeyReferenceFluent<A extends GCPKMSKeyReferenceFluent<A>> extends BaseFluent<A>{
  public GCPKMSKeyReferenceFluent() {
  }
  
  public GCPKMSKeyReferenceFluent(GCPKMSKeyReference instance) {
    this.copyInstance(instance);
  }
  private String keyRing;
  private String location;
  private String name;
  private String projectID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(GCPKMSKeyReference instance) {
    instance = (instance != null ? instance : new GCPKMSKeyReference());
  
    if (instance != null) {
        this.withKeyRing(instance.getKeyRing());
        this.withLocation(instance.getLocation());
        this.withName(instance.getName());
        this.withProjectID(instance.getProjectID());
        this.withKeyRing(instance.getKeyRing());
        this.withLocation(instance.getLocation());
        this.withName(instance.getName());
        this.withProjectID(instance.getProjectID());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getKeyRing() {
    return this.keyRing;
  }
  
  public A withKeyRing(String keyRing) {
    this.keyRing=keyRing; return (A) this;
  }
  
  public boolean hasKeyRing() {
    return this.keyRing != null;
  }
  
  public String getLocation() {
    return this.location;
  }
  
  public A withLocation(String location) {
    this.location=location; return (A) this;
  }
  
  public boolean hasLocation() {
    return this.location != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getProjectID() {
    return this.projectID;
  }
  
  public A withProjectID(String projectID) {
    this.projectID=projectID; return (A) this;
  }
  
  public boolean hasProjectID() {
    return this.projectID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GCPKMSKeyReferenceFluent that = (GCPKMSKeyReferenceFluent) o;
    if (!java.util.Objects.equals(keyRing, that.keyRing)) return false;
  
    if (!java.util.Objects.equals(location, that.location)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(projectID, that.projectID)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(keyRing,  location,  name,  projectID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (keyRing != null) { sb.append("keyRing:"); sb.append(keyRing + ","); }
    if (location != null) { sb.append("location:"); sb.append(location + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (projectID != null) { sb.append("projectID:"); sb.append(projectID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
